@@ -5,7 +5,7 @@ static const char *hlist[] =
 "",
 "--------------------------------------------------------------------------",
 "The automated news update program accepts the following commands:",
-"site, include, exclude, delete, list, newsgroups, help and quit.",
+"site, include, exclude, poison, delete, list, newsgroups, help and quit.",
 "",
 "The 'site' command *must* come prior to any of the other commands.",
 "After that any order of commands is acceptable. Note that commands are",
@@ -17,6 +17,7 @@ static const char *hlist[] =
 "site           <sitename>      <password>",
 "include        <pattern>",
 "exclude        <pattern>",
+"pattern        <pattern>",
 "delete         <pattern>",
 "list",
 "newsgroups     <pattern>",
@@ -43,10 +44,16 @@ static const char *hlist[] =
 "included, except for comp.sys.weirdosystems. In other words it's a merely",
 "a convenient way of refining a large Include list.",
 "",
-"The 'delete' command removes all matching 'include' and 'exclude' patterns",
-"from the current group list.",
+"You can use the poison command to specify pattern which cause all crossposts",
+"to matching groups to be dropped, regardless whether the article would be",
+"accepted due to other groups. Example:",
 "",
- "newsgroups lists out all the valid newsgroups that match the pattern.",
+"poison         *.binari*",
+"",
+"The 'delete' command removes all matching 'include', 'exclude' and 'poison'"
+"patterns from the current group list.",
+"",
+"newsgroups lists out all the valid newsgroups that match the pattern.",
 "",
 "quit is used to stop gup from parsing the rest of the mail, that typically",
 "has signatures and such baggage on the end of it",
